@@ -1,7 +1,7 @@
 from random import randint, choice
 
 
-def combobox(self):
+def combobox():
     """
         It is a function with the equivalent values of the present combobox in the question.
 
